.. pysll documentation master file, created by
   sphinx-quickstart on Tue Feb 27 18:15:04 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pysll's documentation!
=================================

Home for Emerald Cloud Lab's documentation for ``pysll``.

``pysll`` is a package used to automatically run experiments, analyses, and simulations available
on the ECL platform from a simple python interface. You only need an ECL account, and you will have
access to over 200 experiments at your fingertips. This interface makes it easy to integrate large
scale experimental workflows with the powerful machine learning and artificial intelligence ecosystem
available in python.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage/installation
   usage/getting-started
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
